#
# spec file for package flamerobin
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
Name:           flamerobin
Version:        0.9.3.1
Release:        lp150.1.6
Summary:        Graphical client for Firebird
License:        MIT and LGPL-2.1+
Group:          Productivity/Databases/Tools
Url:            http://www.flamerobin.org/
Source0:        https://github.com/mariuz/flamerobin/archive/%{version}.tar.gz
# PATCH-FIX-UPSTREAM flamerobin-desktop-file.patch gh#mariuz/flamerobin#5 badshah400@gmail.com -- Unhardcode icon path in GNU/Linux laucher; patch taken from upstream git
Patch0:         flamerobin-desktop-file.patch
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  icns-utils
BuildRequires:  libfbclient2-devel >= 2.0.0.12748
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel >= 3.0
Requires(post): update-desktop-files
Requires(postun): update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FlameRobin is a database administration tool for Firebird DBMS based on wxgtk
toolkit.

%prep
%setup -q
%patch0 -p1

%build
# FIX A TRAILING SEMICOLON ISSUE FOR KEYWORDS TAG IN .desktop FILE
sed -i "s/^Keywords=firebird/Keywords=firebird;/" res/%{name}.desktop

export CFLAGS="%{optflags} -fpermissive"
export CXXFLAGS="$CFLAGS"
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

%suse_update_desktop_file -r %{name} Office Database
rm -rf %{buildroot}%{_datadir}/%{name}/docs

# INSTALL HICOLOR ICONS EXTRACTED FROM ICNS FILE
pushd res
icns2png -x -d 32 flamerobin.icns
for sz in 16 32 48 128
do
  install -Dm0644 flamerobin_${sz}x${sz}x32.png %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps/%{name}.png
done
popd
rm %{buildroot}%{_datadir}/pixmaps/*.png

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc docs/*
%{_mandir}/man1/flamerobin.1*
%{_bindir}/%{name}
%{_datadir}/applications/*
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Sep 29 2016 badshah400@gmail.com
- Update to version 0.9.3.1:
  + New templating system allows you to add you own SQL statement
    templates to the menu
  + BLOB editor
  + Extended dialog with SQL statement history makes it easier to
    search
  + View dependencies are resolved properly for Firebird 2.5
  + Fixed statistics for UPDATE OR INSERT statements
  + DataGrid: implemented Copy as IN list
  + DataGrid: Fixed keyboard navigation
  + Added new context menu options
  + Fixed error messages when different character set is used in
    statements
  + Warn when closing SQL editor with active transactions
  + Ability to refresh list of objects in the main tree
  + Fixed bug with quoted identifier when altering column type
  + Generate change script is now available for columns as well
  + Fixed truncating of Unicode characters with Firebird 1.5
- Update required version of wxwidgets to >= 3.0.
- Drop flamerobin-0.9.2-wxWindowListNode.patch; fixed upstream.
- Use github tagged tarball for source; update %%setup accordingly.
- Add flamerobin-desktop-file.patch to remove hardcoded reference
  to location of icon file.
- Extract hicolor icons of all possible sizes from bundled icns
  file and install them to hicolor icon dir; adds BuildRequires
  on icns-utils, hicolor-icon-theme; run
  %%icon_theme_cache_post(un) post(un) scriptlets.
- Sed to fix a trailing ';' issue in .desktop file.
* Fri Jul  3 2015 mpluskal@suse.com
- Cleanup spec file with spec-clener
- Update desktop file scriplet dependencies
* Tue May 22 2012 mkubecek@suse.cz
- adjust BuildRequires for Firebird 2.5 packages
* Thu Dec 15 2011 cfarrell@suse.com
- license update: MIT and LGPL-2.1+
  See the Readme - mostly MIT (including the IBPP) but some icons are
  LGPL-2.1+
* Thu Dec  8 2011 coolo@suse.com
- "BSD" is not a valid spdx.org license
* Tue Oct  4 2011 mhrusecky@suse.cz
- Adding '-fpermissive' to fix build on Factory
* Wed Dec 29 2010 sbrabec@suse.cz
- Compile with wxWidgets (STL variant).
* Fri Jul  3 2009 mhrusecky@suse.cz
- Fixed build with wxUSE_STL enabled
* Tue Jun 30 2009 makowski@firebird-fr.eu.org
- First OpenSuse build
* Sun Apr 12 2009 makowski@firebird-fr.eu.org
- First Fedora build
- New upstream: 0.9.2
* Tue Mar 24 2009 makowski@firebird-fr.eu.org
- Update to 0.9.0
- First mipsel build
* Thu Jul 24 2008 tvignaud@mandriva.com
  + Revision: 245195
- rebuild
* Thu Jan 31 2008 mrl@mandriva.com
  + Revision: 160873
- New upstream: 0.8.3
  + Olivier Blin <oblin@mandriva.com>
  - restore BuildRoot
  + Thierry Vignaud <tvignaud@mandriva.com>
  - kill re-definition of %%%%buildroot on Pixel's request
* Thu Oct 18 2007 mrl@mandriva.com
  + Revision: 99959
- Fix configure permission.
- New upstream: 0.8.1
- New upstream: 0.8.0
* Tue May 15 2007 mrl@mandriva.com
  + Revision: 26964
- Rebuilt against new wx stuff.
* Wed Dec 20 2006 waschk@mandriva.org
  + Revision: 100700
- rebuild
* Mon Nov 27 2006 mrl@mandriva.com
  + Revision: 87367
- New upstream: 0.7.6
- Added menu icon.
* Thu Nov 16 2006 mrl@mandriva.com
  + Revision: 84903
- Added BuildRequires for ImageMagick: due to convert usage.
- Rebuilt against firebird 2.0 final.
* Thu Sep  7 2006 mrl@mandriva.com
  + Revision: 60258
- New upstream: 0.7.5
* Wed Sep  6 2006 mrl@mandriva.com
  + Revision: 59989
- Removed old-style menu entry. The new one (.desktop) will be added later.
- Import flamerobin
* Sat Sep  2 2006 mrl@mandriva.com
- Fixed BuildRequires.
- Removed hardcoded buildrequires to libraries: they should be automatic.
- Enhanced package description.
* Thu Aug 24 2006 makowski@firebird-fr.eu.org
- change Requires to libfirebird2
